@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 
 from .processor import *
-from .downloader import *
-from .main import *
-from .common import script_main
 
-__version__ = common.proj_info['version']
+from .downloader import *
+
+from .version import *
+from .common import *
+from .main import *
