@@ -4,17 +4,25 @@ from .acfun import *
 from .bilibili import *
 from .cntv import *
 from .dailymotion import *
+from .facebook import *
 from .googleplus import *
 from .ifeng import *
 from .iqiyi import *
+from .joy import *
 from .ku6 import *
+from .mixcloud import *
+from .netease import *
+from .nicovideo import *
 from .pptv import *
 from .qq import *
 from .sina import *
 from .sohu import *
+from .soundcloud import *
 from .tudou import *
+from .tumblr import *
 from .vimeo import *
 from .w56 import *
+from .xiami import *
 from .yinyuetai import *
 from .youku import *
 from .youtube import *
