@@ -18,26 +18,35 @@ def url_to_module(url):
     
     k = r1(r'([^.]+)', domain)
     downloads = {
+        '163': netease,
         '56': w56,
         'acfun': acfun,
         'bilibili': bilibili,
         'cntv': cntv,
         'dailymotion': dailymotion,
+        'facebook': facebook,
         'google': googleplus,
         'iask': sina,
         'ifeng': ifeng,
         'iqiyi': iqiyi,
+        'joy': joy,
         'kankanews': bilibili,
         'ku6': ku6,
+        'mixcloud': mixcloud,
+        'nicovideo': nicovideo,
         'pptv': pptv,
         'qq': qq,
         'sina': sina,
         'smgbb': bilibili,
         'sohu': sohu,
+        'soundcloud': soundcloud,
         'tudou': tudou,
+        'tumblr': tumblr,
         'vimeo': vimeo,
+        'xiami': xiami,
         'yinyuetai': yinyuetai,
         'youku': youku,
+        'youtu': youtube,
         'youtube': youtube,
         #TODO
     }
